"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.startFrameworkService = startFrameworkService;
const function_loader_1 = require("./function-loader");
const logger_1 = require("./logger");
const server_1 = require("./server");
const tools_1 = require("./tools");
async function startFrameworkService(options) {
    Error.stackTraceLimit = 100;
    if (options.interceptOutput) {
        logger_1.Interceptor.intercept();
    }
    if (options.noExit) {
        (0, tools_1.interceptProcessExit)();
    }
    const loadResult = await (0, function_loader_1.loadUserFunction)(options.sourceLocation, options.target);
    if (!loadResult?.userFunction) {
        logger_1.frameworkLogger.error(`Failed to load target function, because "${loadResult?.reason}"`);
        process.forceExit(1);
    }
    if (options.dryRun) {
        process.forceExit(0);
    }
    const opt = {
        dirname: options.logDirname,
        maxSize: options.maxLogFileSize,
        maxFiles: options.maxLogFiles
    };
    logger_1.functionsLogger.init([
        { type: logger_1.FunctionsLoggerType.ACCESS, options: opt },
        { type: logger_1.FunctionsLoggerType.USERCODE, options: opt }
    ]);
    const { userFunction } = loadResult;
    const server = (0, server_1.createServer)(userFunction, options);
    const signalHandler = new tools_1.ServerSignalHandler(server, options.gracefulShutdown);
    server.listen(options.port, () => {
        signalHandler.setup();
        logger_1.frameworkLogger.info(`Server listening on port ${options.port}`);
        logger_1.frameworkLogger.info(`Framework options: ${JSON.stringify(options)}`);
    });
    server.timeout = 0;
    server.keepAliveTimeout = options.keepAliveTimeoutMS;
}
//# sourceMappingURL=framework.js.map