"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.wrapHandlerFunction = wrapHandlerFunction;
const util_1 = require("util");
const constants_1 = require("./constants");
const error_1 = require("./error");
const function_sse_1 = require("./function-sse");
const unified_responder_1 = require("./unified-responder");
const wrapEventFunction = (execute, captureStack, logEventContext) => {
    return async (ctx) => {
        let event;
        if (ctx.request.files) {
            // form-data, restructured to form-data like object
            event = { ...ctx.request.files, ...ctx.request.body };
            ctx.state.eventString = logEventContext ? (0, util_1.inspect)(event, { depth: 2, maxStringLength: constants_1.LOG_MAX_EVENT_LENGTH }) : '';
        }
        else if (ctx.request.body) {
            // normal json, text etc. that can be parsed
            event = ctx.request.body;
            ctx.state.eventString = logEventContext ? (0, util_1.inspect)(event, { depth: 5, maxStringLength: constants_1.LOG_MAX_EVENT_LENGTH }) : '';
        }
        else {
            // unrecognized, send raw body
            event = ctx.rawBody;
            ctx.state.eventString = logEventContext ? (0, util_1.inspect)(event, { depth: 1, maxStringLength: constants_1.LOG_MAX_EVENT_LENGTH }) : '';
        }
        let executeDone = false;
        let hasSwitchSSEMode = false;
        const context = {
            eventID: ctx.state.eventID,
            eventType: ctx.state.eventType,
            timestamp: ctx.state.timestamp,
            tcbContext: ctx.state.tcbContext,
            wechatContext: ctx.state.wechatContext,
            httpContext: ctx.httpContext,
            sse: () => {
                // 已经响应或函数执行完，无法切换到SSE
                if (ctx.res.headersSent || executeDone) {
                    return null;
                }
                hasSwitchSSEMode = true;
                return new function_sse_1.SeverSentEvent(ctx);
            }
        };
        ctx.state.contextString = JSON.stringify(context);
        let result;
        const start = Date.now();
        try {
            result = await execute(event, context);
        }
        catch (e) {
            ctx.state.error = e;
        }
        finally {
            ctx.state.userTimeCost = Date.now() - start;
        }
        executeDone = true;
        if (hasSwitchSSEMode) {
            return;
        }
        const e = ctx.state.error ? (0, error_1.newSysErr)(ctx.state.error) : null;
        return (0, unified_responder_1.sendResponse)(ctx, result, e, undefined, captureStack);
    };
};
function wrapHandlerFunction(userFunction, type, captureStack = false, logEventContext = false) {
    switch (type) {
        case 'event':
            return wrapEventFunction(userFunction, captureStack, logEventContext);
        default:
            throw new Error(`Unsupported function type: ${type}`);
    }
}
//# sourceMappingURL=function-wrapper.js.map