"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.removeAllContextHeaders = exports.extractWeChatContextFromHeader = exports.extractTCBContextFromHeader = void 0;
const zlib_1 = require("zlib");
const TCBContextHeaderKey = 'X-Tcb-Context';
const WeChatContextHeaderKey = 'X-Wechat-Context';
/**
 * extractContextFromHTTPHeader 从 HTTP 请求头中提取上下文
 * @param headers
 * @param headerKey
 * @returns
 */
function extractContextFromHTTPHeader(headers, headerKey) {
    const empty = {};
    if (!headerKey) {
        return empty;
    }
    const headerValue = headers[headerKey.toLowerCase()];
    if (!headerValue) {
        return empty;
    }
    // Encode Base64 first, then gunzip
    try {
        const unzipped = (0, zlib_1.gunzipSync)(Buffer.from(headerValue, 'base64')).toString('utf-8');
        return JSON.parse(unzipped);
    }
    catch (e) {
        return empty;
    }
}
/**
 * extractTCBContextFromHeader 从 HTTP 请求头中提取 TCB 调用上下文
 * @param headers  HTTP 请求头
 * @returns  TCB 调用上下文
 */
const extractTCBContextFromHeader = (headers) => {
    return extractContextFromHTTPHeader(headers, TCBContextHeaderKey);
};
exports.extractTCBContextFromHeader = extractTCBContextFromHeader;
/**
 * extractWeChatContextFromHeader 从 HTTP 请求头中提取微信调用上下文
 * @param headers  HTTP 请求头
 * @returns  微信调用上下文
 */
const extractWeChatContextFromHeader = (headers) => {
    return extractContextFromHTTPHeader(headers, WeChatContextHeaderKey);
};
exports.extractWeChatContextFromHeader = extractWeChatContextFromHeader;
const removeContextHeaders = (headers, targetKeys) => {
    const newHeaders = { ...headers };
    for (const target of targetKeys) {
        const th = target.toLowerCase();
        if (newHeaders[th]) {
            delete newHeaders[th];
        }
    }
    return newHeaders;
};
const removeAllContextHeaders = (headers) => {
    return removeContextHeaders(headers, [TCBContextHeaderKey, WeChatContextHeaderKey]);
};
exports.removeAllContextHeaders = removeAllContextHeaders;
//# sourceMappingURL=invoker.js.map